View source: R/get_eurostat_dic.R
| get_eurostat_dic | R Documentation |
Download a Eurostat dictionary.
get_eurostat_dic(dictname, lang = "en")
dictname |
A character, dictionary for the variable to be downloaded. |
lang |
A character, language code. Options: "en" (default), "fr", "de". |
For given coded variable from Eurostat
https://ec.europa.eu/eurostat/. The dictionaries link codes with
human-readable labels. To translate codes to labels, use
label_eurostat().
tibble with two columns: code names and full names.
Przemyslaw Biecek and Leo Lahti leo.lahti@iki.fi. Thanks to Wietse Dol for contributions. Updated by Pyry Kantanen to support XML codelists.
See citation("eurostat"):
# Kindly cite this package by citing the following R Journal article: # # Lahti L., Huovari J., Kainu M., and Biecek P. (2017). Retrieval and # analysis of Eurostat open data with the eurostat package. The R # Journal 9(1), pp. 385-392. doi: 10.32614/RJ-2017-019 # # In addition, please provide a citation to the specific software version # used: # # Lahti L, Huovari J, Kainu M, Biecek P, Hernangomez D, Antal D, # Kantanen P (2026). "eurostat: Tools for Eurostat Open Data." # doi:10.32614/CRAN.package.eurostat # <https://doi.org/10.32614/CRAN.package.eurostat>. R package version # 4.1.1, <https://github.com/rOpenGov/eurostat>. # # To see these entries in BibTeX format, use 'print(<citation>, # bibtex=TRUE)', 'toBibtex(.)', or set # 'options(citation.bibtex.max=999)'.
label_eurostat(), get_eurostat(),
search_eurostat().
get_eurostat_dic("crop_pro")
# Try another language
get_eurostat_dic("crop_pro", lang = "fr")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.