View source: R/get_eurostat_local.R
| get_eurostat_local | R Documentation |
Read compressed or uncompressed SDMX-CSV files
get_eurostat_local(
file,
time_format = "date",
type = "code",
lang = "en",
select_time = NULL,
stringsAsFactors = FALSE,
keepFlags = FALSE,
legacy.data.output = FALSE
)
file |
file path as string |
time_format |
a string giving a type of the conversion of the time column from the
eurostat format. The default argument " |
type |
A type of variables, " |
lang |
2-letter language code, default is " |
select_time |
a character symbol for a time frequency or |
stringsAsFactors |
if |
keepFlags |
a logical whether the flags (e.g. "confidential",
"provisional") should be kept in a separate column or if they
can be removed. Default is |
legacy.data.output |
Use legacy column names and data object structure. Default is FALSE. If TRUE, the object will try to emulate the naming conventions of eurostat package version 3.7.x and earlier. |
This implementation is experimental. It uses only data.table methods to read and wrangle data files.
Download datasets in sdmx-csv format from https://ec.europa.eu/eurostat/databrowser/bulk?lang=en
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.