View source: R/get_eurostat_sdmx.R
| get_eurostat_sdmx | R Documentation |
Download data sets from Eurostat using the same logic as get_eurostat()
function.
get_eurostat_sdmx(
id,
time_format = "date",
filters = NULL,
type = "code",
lang = "en",
use.data.table = FALSE,
agency = "Eurostat",
compressed = TRUE,
keepFlags = FALSE,
legacy.data.output = FALSE,
wait = 10,
max_wait = 600,
verbose = TRUE
)
id |
A unique identifier / code for the dataset of interest. If code is not
known |
time_format |
a string giving a type of the conversion of the time column from the
eurostat format. The default argument " |
filters |
A named list of filters. Names of list objects are Eurostat
variable codes and values are vectors of observation codes. If |
type |
A type of variables, " |
lang |
2-letter language code, default is " |
use.data.table |
Use data.table to process files? Default is FALSE.
If data.table is used, data will be downloaded as a TSV file and
processed using |
agency |
Either "Eurostat" (default), "Eurostat_comext" (for Comext and Prodcom datasets), "COMP", "EMPL" or "GROW" |
compressed |
Logical. Download data in compressed format? Default is TRUE. |
keepFlags |
a logical whether the flags (e.g. "confidential",
"provisional") should be kept in a separate column or if they
can be removed. Default is |
legacy.data.output |
Use legacy column names and data object structure. Default is FALSE. If TRUE, the object will try to emulate the naming conventions of eurostat package version 3.7.x and earlier. |
wait |
Integer. Seconds between status checks. Default is 1 second. |
max_wait |
Integer. Max time to wait in seconds. Default is 60 seconds. |
verbose |
Output messages when downloading data. Default is |
This function is experimental because while it works as intended and is useful in the same way as other get_ functions in the package, we would like to test it for a while and listen to user feedback before deciding on what is the best way to interact with SDMX APIs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.