Transform raw Eurostat TSV files downloaded from the API into a tidy row-column-value format (RCV).
Usage
tidy_eurostat(
dat,
time_format = "date",
select_time = NULL,
stringsAsFactors = FALSE,
keepFlags = FALSE,
use.data.table = FALSE
)Arguments
- dat
a data_frame from
get_eurostat_raw().- time_format
a string giving a type of the conversion of the time column from the eurostat format. The default argument "
date" converts to abase::Date()class with the date being the first day of the period. A "date_last" argument converts the dataset date to abase::Date()class object with the difference that the exact date is the last date of the period. Period can be year, semester (half year), quarter, month, or week (Seeeurotime2date()for more information). Argument "num" converts the date into a numeric (integer) meaning that the first day of the year 2000 is close to 2000.01 and the last day of the year is close to 2000.99 (seeeurotime2num()for more information). Using the argument "raw" preserves the dates as they were in the original Eurostat data.- select_time
a character symbol for a time frequency or
NULL, which is used by default as most datasets have just one time frequency. For datasets with multiple time frequencies, select one or more of the desired frequencies with: "Y" (or "A") = annual, "S" = semi-annual / semester, "Q" = quarterly, "M" = monthly, "W" = weekly. For all frequencies in same data frametime_format = "raw"should be used.- stringsAsFactors
if
TRUE(the default) variables are converted to factors in the original Eurostat order. IfFALSEthey are returned as strings.- keepFlags
a logical whether the flags (e.g. "confidential", "provisional") should be kept in a separate column or if they can be removed. Default is
FALSE. For flag values see information: https://ec.europa.eu/eurostat/data/database#Flags. Also possible non-real zero "0n" is indicated in flags column. Flags are not available for eurostat API, sokeepFlagscan not be used with afilters.- use.data.table
Use faster data.table functions? Default is FALSE. On Windows requires that RTools is installed.
References
See citation("eurostat"):
Kindly cite this package by citing the following R Journal article:
Lahti L., Huovari J., Kainu M., and Biecek P. (2017). Retrieval and
analysis of Eurostat open data with the eurostat package. The R
Journal 9(1), pp. 385-392. doi: 10.32614/RJ-2017-019
In addition, please provide a citation to the specific software version
used:
Lahti L, Huovari J, Kainu M, Biecek P, Hernangomez D, Antal D,
Kantanen P (2026). "eurostat: Tools for Eurostat Open Data."
doi:10.32614/CRAN.package.eurostat
<https://doi.org/10.32614/CRAN.package.eurostat>. R package version
4.1.0, <https://github.com/rOpenGov/eurostat>.
To see these entries in BibTeX format, use 'print(<citation>,
bibtex=TRUE)', 'toBibtex(.)', or set
'options(citation.bibtex.max=999)'.When citing data downloaded from Eurostat, see section "Citing Eurostat data"
in get_eurostat() documentation.
Examples
if (FALSE) { # \dontrun{
# Example of a dataset with multiple time series
get_eurostat("AVIA_GOR_ME",
time_format = "date_last",
cache = F
)
} # }