View source: R/tidy_eurostat.R
| tidy_eurostat_sdmx_csv | R Documentation |
Transform raw Eurostat TSV files downloaded from the API into a tidy row-column-value format (RCV).
tidy_eurostat_sdmx_csv(
dat,
time_format = "date",
select_time = NULL,
keepFlags = FALSE
)
dat |
a data_frame from |
time_format |
a string giving a type of the conversion of the time column from the
eurostat format. The default argument " |
select_time |
a character symbol for a time frequency or |
keepFlags |
a logical whether the flags (e.g. "confidential",
"provisional") should be kept in a separate column or if they
can be removed. Default is |
Can read only SDMX-CSV files, in compressed (.csv.gz) and uncompressed (.csv)
format. As opposed to regular tidy_eurostat function, stringsAsFactors is
determined outside this function, in get_eurostat_local().
data.table object in the melted format with the last column 'values' or 'OBS_VALUE'.
Pyry Kantanen
See citation("eurostat"):
Kindly cite this package by citing the following R Journal article: Lahti L., Huovari J., Kainu M., and Biecek P. (2017). Retrieval and analysis of Eurostat open data with the eurostat package. The R Journal 9(1), pp. 385-392. doi: 10.32614/RJ-2017-019 In addition, please provide a citation to the specific software version used: Lahti L, Huovari J, Kainu M, Biecek P, Hernangomez D, Antal D, Kantanen P (2026). "eurostat: Tools for Eurostat Open Data." doi:10.32614/CRAN.package.eurostat <https://doi.org/10.32614/CRAN.package.eurostat>. R package version 4.1.1, <https://github.com/rOpenGov/eurostat>. To see these entries in BibTeX format, use 'print(<citation>, bibtex=TRUE)', 'toBibtex(.)', or set 'options(citation.bibtex.max=999)'.
When citing data downloaded from Eurostat, see section "Citing Eurostat data"
in get_eurostat() documentation.
get_eurostat_local()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.